@@ -24,9 +24,9 @@ NullGesture::NullGesture(Device *device, libconfig::Setting& setting) :
 {
 }
 
-void NullGesture::press()
+void NullGesture::press(bool init_threshold)
 {
-    _axis = 0;
+    _axis = init_threshold ? _config.threshold() : 0;
 }
 
 void NullGesture::release(bool primary)
@@ -40,6 +40,11 @@ void NullGesture::move(int16_t axis)
     _axis += axis;
 }
 
+bool NullGesture::wheelCompatibility() const
+{
+    return true;
+}
+
 bool NullGesture::metThreshold() const
 {
     return _axis > _config.threshold();
