@@ -28,10 +28,11 @@ namespace actions
     public:
         NullGesture(Device* device, libconfig::Setting& setting);
 
-        virtual void press();
+        virtual void press(bool init_threshold=false);
         virtual void release(bool primary=false);
         virtual void move(int16_t axis);
 
+        virtual bool wheelCompatibility() const;
         virtual bool metThreshold() const;
     protected:
         int16_t _axis;
